@@ -2,6 +2,7 @@ from abc import ABC
 from typing import Dict, Union, Tuple
 
 import pandas as pd
+import numpy as np
 import numpy.typing as npt
 
 from sakkara.model.fixed.base import FixedValueComponent
@@ -11,7 +12,7 @@ from sakkara.relation.representation import TensorRepresentation
 
 class DataComponent(FixedValueComponent, ABC):
     """
-    Wrap data, of some given colums, into a component
+    Wrap data into a component
 
     :param data: Array of data to wrap.
     :param group: Group(s) of which the component is defined for. The number of elements should correspond to the
@@ -19,8 +20,11 @@ class DataComponent(FixedValueComponent, ABC):
     :param name: Name of the component.
     """
 
-    def __init__(self, data: Union[npt.NDArray, pd.Series], group: Union[str, Tuple[str, ...]], name: str = None):
-        super().__init__(data.values if isinstance(data, pd.Series) else data, group, name)
+    def __init__(self, data: Union[npt.NDArray, float, int], group: Union[str, Tuple[str, ...]], name: str = None):
+        if isinstance(data, np.ndarray):
+            super().__init__(data, group, name)
+        else:
+            super().__init__(np.array([data]), group, name)
 
     def build_representation(self, groupset: GroupSet) -> None:
         self.representation = TensorRepresentation()
@@ -38,4 +42,4 @@ def data_components(df: pd.DataFrame) -> Dict[str, DataComponent]:
     :return: Dictionary of {<column name in DataFrame>: :class:`DataComponent`}
 
     """
-    return {k: DataComponent(df[k], 'obs', k) for k in df}
+    return {k: DataComponent(df[k].values, 'obs', k) for k in df}
